#ifndef NT2_INCLUDE_FUNCTIONS_KNUTH_EQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_KNUTH_EQUAL_HPP_INCLUDED

#include <nt2/fuzzy/include/functions/knuth_equal.hpp>

#endif
